﻿Copyright (c) (2017) Fluke Corporation                      MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Tek TDS6000 Record Reading IEEE
INSTRUMENT:            Sub Tek TDS6000 Cursor Walker IEEE
INSTRUMENT:            Sub Tek TDS6000 Main Trigger IEEE
INSTRUMENT:            Sub Tek TDS6000 Delay Trigger IEEE
INSTRUMENT:            Sub Tek TDS6000 Cursor Reading IEEE
INSTRUMENT:            Sub Tek TDS6000 Check for Trigger IEEE
DATE:                  2018-09-10 11:00:23
AUTHOR:                Fluke Corporation
REVISION:              $Revision: 24954 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       7
NUMBER OF LINES:       412
=============================================================================
#
#  Procedure Author:
#        DAC, ZY
#
#  Source:
#        Tektronix TDS6000 Series Service Manual,
#        Performance Verification, and Specifications
#
#  Compatibility:
#        MET/CAL 8.0 or later
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
# REGISTERS USED:
#
#   You will notice that MEM & MEM1 are used extensively in this procedure.
#   This can be dangerous to use since MEM and MEM1 are used for controlling
#   instruments.  We read the values from MEM and MEM1 and store these in
#   temporary registers which are later restored on exiting the sub-procedure.
#
#   M[1]
#     This register is the horizontal start position for the Cursor Walker
#     subprocedure.
#
#   M[2]
#     This register is the horizontal increment for the Cursor Walker
#     subprocedure.
#
#   M[3]
#     This register is the horizontal position for the Cursor Walker
#     subprocedure.
#     This register is the starting trigger level for the Main Trigger
#     and Delay Trigger subprocedures.
#
#   M[4]
#     This register is the trigger level increment for the Main Trigger
#     and Delay Trigger subprocedures.
#
#   M[5]
#     This register is the trigger level for the Main Trigger and Delay
#     Trigger subprocedures.  It is also used to "remember" the previous
#     amplitude in the Cursor Walker subprocedure.
#
#   M[10]
#     This variable is used to set watchdog timer in the event the
#     oscillscope does not respond to a command.
#
#   BackupMEM
#     This variable is used to store the value of MEM
#
#   BackupMEM1
#     This variable is used to store the value of MEM1
#
#   M[20]
#     This variable to designate Main (=0) vs Delay (=1) trigger adjust
#
#   S[6]
#     This variable is used to store the trigger "MAIN" or "DELAY".
#
# If the Master Counter is more than 100, we have not been able to
# generate a stable trigger
# Determine which horizontal position resulted in a vertical amplitude
# closest to the target amplitude.
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  MATH         BackupMEM = MEM; BackupMEM1 = MEM1

  1.002  JMPL         RECORD_READING               PSUB("Record Reading")
  1.003  JMPL         CURSOR_WALKER                PSUB("Cursor Walker")
  1.004  JMPL         MAIN_TRIGGER                 PSUB("Main Trigger")
  1.005  JMPL         DELAY_TRIGGER                PSUB("Delay Trigger")
  1.006  JMPL         CURSOR_READING               PSUB("Cursor Reading")
  1.007  JMPL         CHECK_FOR_TRIGGER            PSUB("Check for Trigger")
  1.008  DISP         Undefined subprocedure!
  1.009  END

  1.010  EVAL   Increment test number

# =====  Sub Tek TDS6000 Record Reading IEEE  ===============================

  2.001  LABEL        RECORD_READING
# Reset the watchdog counter
  2.002  MATH         M[10] = 0

  2.003  LABEL        CHECK_FOR_STABLE_READING
# We will go through this loop 50 times.  If there is not a good reading
# then we will warn the operator

  2.004  MATH         M[10] = M[10] + 1
  2.005  JMPL         UNSTABLE_READING             M[10] > 50

  2.006  LABEL        READING1
  2.007  MATH         @Cmd = "ACQUIRE:STATE RUN"
  2.008  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
  2.009  JMPL         RESTORE_MEM_AND_MEM1         @Abort
  2.010  IEEE         [V @MeasQuery][I]
  2.011  MATH         L[14] = MEM
  2.012  HEAD         Channel Reading = [MEM]
  2.013  IEEE         [D350]

  2.014  LABEL        READING2
  2.015  MATH         @Cmd = "ACQUIRE:STATE RUN"
  2.016  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
  2.017  JMPL         RESTORE_MEM_AND_MEM1         @Abort
  2.018  IEEE         [V @MeasQuery][I]
  2.019  MATH         L[15] = MEM
  2.020  HEAD         Channel Reading = [MEM]
  2.021  IEEE         [D350]

  2.022  LABEL        READING3
  2.023  MATH         @Cmd = "ACQUIRE:STATE RUN"
  2.024  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
  2.025  JMPL         RESTORE_MEM_AND_MEM1         @Abort
  2.026  IEEE         [V @MeasQuery][I]
  2.027  HEAD         Channel Reading = [MEM]
  2.028  MATH         L[16] = MEM

  2.029  MATH         L[18] = MIN_L(14, 16)
  2.030  MATH         L[19] = MAX_L(14, 16)

# We picked a value of 5 times the resolution of the
# measurement to determine a stable reading.  Other
# factors like noise or condition of the scope will
# have a factor in this.

  2.031  MATH         L[20] = ABS(L[18] - L[19])
  2.032  JMPL         CHECK_FOR_STABLE_READING     L[20] > (5.0 * M[17])
  2.033  JMPL         TAKE_READING

  2.034  LABEL        UNSTABLE_READING
  2.035  OPBR         -z The Scope has encountered an unstable value.
  2.035  OPBR         Do you wish to take more readings?
  2.036  JMPL         RECORD_READING               MEM1

# Take one more reading and use it
  2.037  LABEL        TAKE_READING
  2.038  MATH         @Cmd = "ACQUIRE:STATE RUN"
  2.039  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
  2.040  JMPL         RESTORE_MEM_AND_MEM1         @Abort
  2.041  IEEE         [V @MeasQuery][I]
  2.042  HEAD         Channel Reading = [MEM]
# Note, MEM is restored from BackupMEM at bottom of this procedure.
  2.043  MATH         BackupMEM = MEM
  2.044  JMPL         RESTORE_MEM_AND_MEM1

  2.045  EVAL   Increment test number

# =====  Sub Tek TDS6000 Cursor Walker IEEE  ================================

# This function moves cursor 1 a step at a time until it finds the target
# amplitude of the waveform specified in M[4]. It "returns" a value in
# MEM that is equal to the time at which the amplitude happens.

  3.001  LABEL        CURSOR_WALKER
# Initialize horizontal position (s) and previous vertical amplitude (V).
  3.002  MATH         M[3] = M[1]; M[5] = 0
  3.003  MATH         @Cmd = "CURSOR:PAIRED:POSITION1 " & M[3]
  3.004  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
  3.005  JMPL         RESTORE_MEM_AND_MEM1         @Abort
  3.006  IEEE         [D500]

  3.007  LABEL        WALK_UPRIGHT
# Move the cursor to the horizontal position.
  3.008  MATH         @Cmd = "CURSOR:PAIRED:POSITION1 " & M[3]
  3.009  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
  3.010  JMPL         RESTORE_MEM_AND_MEM1         @Abort
# Read the vertical amplitude. Throwaway one reading.
  3.011  IEEE         [D100]CURSOR:PAIRED:HPOS1?[I]
# If vertical amplitude has passed the target value, exit the loop.
  3.012  JMPL         STOP_WALKING                 MEM > M[4]
# Save vertical amplitude for next iteration.
  3.013  MATH         M[5] = MEM
# Increment the horizontal position.
  3.014  MATH         M[3] = M[3] + M[2]
  3.015  JMPL         WALK_UPRIGHT

  3.016  LABEL        STOP_WALKING
  3.017  MATH         MEM1 = ABS(MEM - M[4]) < ABS(M[5] - M[4])
  3.018  JMPL         SAVE_HORZ_POS                MEM1
# Use the previous horizontal position.
  3.019  MATH         M[3] = M[3] - M[2]; MEM = M[5]

  3.020  LABEL        SAVE_HORZ_POS
# 3.020  MATH         S[20] = FMT((M[3] / 1E-12), "%.1f")
# 3.021  MATH         S[21] = FMT((MEM / 1E-3), "%.2f")
# 3.022  DISP         Horz. Pos. [S20] ps, Vert. Ampl. [S21] mV, Limit [M4] V
# Note, MEM is restored from BackupMEM at bottom of this procedure.
  3.021  MATH         BackupMEM = M[3]
  3.022  JMPL         RESTORE_MEM_AND_MEM1

  3.023  EVAL   Increment test number

# =====  Sub Tek TDS6000 Main Trigger IEEE  =================================

  4.001  LABEL        MAIN_TRIGGER
  4.002  MATH         M[20] = 0

  4.003  LABEL        CHECK_MAIN_TRIGGER
# Turn delayed trigger (B) off in case it was on.
  4.004  IEEE         TRIG:B:STATE OFF
  4.005  MATH         M[1]  = 0
  4.006  MATH         M[10] = 0
# Set starting trigger level.
  4.007  MATH         M[5] = M[3]
  4.008  MATH         @Cmd = "TRIG:A:LEVEL " & M[5]
  4.009  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
  4.010  JMPL         RESTORE_MEM_AND_MEM1         @Abort

  4.011  LABEL        TEST_MAIN_LEVEL
# Increment Master Watchdog counter
  4.012  MATH         M[1] = M[1] + 1
# If the Master Counter is more than 100, we have not been able to
# generate a stable trigger
  4.013  JMPL         FAIL_MAIN_TRIGGER            M[1] >= 100
# Read the Trigger State
  4.014  IEEE         [D250]TRIG:STATE?[I$]
  4.015  JMPL         PART_OR_TRIG                 M[20] > 0

# If MAIN TRIGGER was called directly the response must TRIGgered.
  4.016  MATH         MEM1 = FIND(MEM2, "TRIG", 1)
  4.017  JMPL         CHECK_MAIN_RESPONSE

  4.018  LABEL        PART_OR_TRIG
# If MAIN TRIGGER was called from DELAY TRIGGER, PARTial or TRIGgered is ok.
  4.019  MATH         MEM1 = FIND(MEM2, "TRIG", 1) + FIND(MEM2, "PART", 1)

  4.020  LABEL        CHECK_MAIN_RESPONSE
  4.021  JMPL         ADJUST_MAIN_LEVEL            MEM1 < 1
# Increment the good trigger counter
  4.022  MATH         M[10] = M[10] + 1
# Jump out of the loop if the system records over 10 good triggers
  4.023  JMPL         END_MAIN_TRIGGER             M[10] > 10
# Go back to the trigger beginning
  4.024  JMPL         TEST_MAIN_LEVEL

  4.025  LABEL        ADJUST_MAIN_LEVEL
# Reset the good trigger counter
  4.026  MATH         M[10] = 0
# If we counted too high, start over
  4.027  JMPL         INCREMENT_MAIN_LEVEL         M[5] < ABS(M[3])
  4.028  MATH         M[5] = M[3]

  4.029  LABEL        INCREMENT_MAIN_LEVEL
  4.030  MATH         M[5] = M[5] + M[4]
  4.031  MATH         @Cmd = "TRIG:A:LEVEL " & M[5]
  4.032  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
  4.033  JMPL         RESTORE_MEM_AND_MEM1         @Abort
  4.034  HEAD         MAIN TRIGGER LEVEL: [M5]V
  4.035  JMPL         TEST_MAIN_LEVEL

  4.036  LABEL        FAIL_MAIN_TRIGGER
# Set a value for M[10] which will later be evaluated as a failure
  4.037  MATH         M[10] = 0

  4.038  LABEL        END_MAIN_TRIGGER
  4.039  JMPL         CHECK_DELAY_TRIGGER          M[20] > 0
  4.040  JMPL         RESTORE_MEM_AND_MEM1

  4.041  EVAL   Increment test number

# =====  Sub Tek TDS6000 Delay Trigger IEEE  ================================

  5.001  LABEL        DELAY_TRIGGER
  5.002  MATH         M[20] = 1

  5.003  LABEL        CHECK_DELAY_TRIGGER
  5.004  IEEE         TRIG:B:STATE ON
# Set a flag
  5.005  MATH         M[1]  = 0
  5.006  MATH         M[10] = 0
# Set starting trigger level.
  5.007  MATH         M[5] = M[3]
  5.008  MATH         @Cmd = "TRIG:B:LEVEL " & M[5]
  5.009  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
  5.010  JMPL         RESTORE_MEM_AND_MEM1         @Abort

  5.011  LABEL        TEST_DELAY_LEVEL
# Increment Master Watchdog counter
  5.012  MATH         M[1] = M[1] + 1
# If the Master Counter is more than 100, we have not been able to
# generate a stable trigger
  5.013  JMPL         FAIL_DELAY_TRIGGER           M[1] >= 100
# Read the Trigger State
  5.014  IEEE         [D250]TRIG:STATE?[I$]
# If "REAdy", we need to re-adjust the main trigger level.
  5.015  JMPL         CHECK_MAIN_TRIGGER           FIND(MEM2, "REA", 1)
  5.016  MATH         MEM1 = FIND(MEM2, "TRIG", 1)
# If "PARTial", we need to adjust the delay trigger Level.
# 5.017  JMPL         ADJUST_DELAY_LEVEL           FIND(MEM2, "PART", 1)
# Increment the good trigger counter
  5.017  MATH         M[10] = M[10] + 1
# Jump out of the loop if the system records over 10 good triggers
  5.018  JMPL         END_DELAY_TRIGGER            M[10] > 10
# Go back to the trigger beginning
  5.019  JMPL         TEST_DELAY_LEVEL

  5.020  LABEL        ADJUST_DELAY_LEVEL
# Reset the good trigger counter
  5.021  MATH         M[10] = 0.0
# If we counted too high, start over
  5.022  JMPL         DELAY_ADD_LEVEL              M[5] < ABS(M[3])
  5.023  MATH         M[5] = M[3]

  5.024  LABEL        DELAY_ADD_LEVEL
  5.025  MATH         M[5] = M[5] + M[4]
  5.026  MATH         @Cmd = "TRIG:B:LEVEL " & M[5]
  5.027  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
  5.028  JMPL         RESTORE_MEM_AND_MEM1         @Abort
  5.029  HEAD         DELAY TRIGGER LEVEL: [M5]V
  5.030  JMPL         TEST_DELAY_LEVEL

  5.031  LABEL        FAIL_DELAY_TRIGGER
# Set a value for M[10] which will later be evaluated as a failure
  5.032  MATH         M[10] = 0

  5.033  LABEL        END_DELAY_TRIGGER
  5.034  JMPL         RESTORE_MEM_AND_MEM1

  5.035  EVAL   Increment test number

# =====  Sub Tek TDS6000 Cursor Reading IEEE  ===============================

  6.001  LABEL        CURSOR_READING
  6.002  MATH         @Cmd = "ACQ:STATE RUN"
  6.003  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
  6.004  JMPL         RESTORE_MEM_AND_MEM1         @Abort
  6.005  IEEE         [V @MeasQuery][I]
  6.006  MATH         M[14] = MEM
  6.007  HEAD         Channel Reading = [MEM]
  6.008  IEEE         [D350]

  6.009  LABEL        READING2
  6.010  MATH         @Cmd = "ACQ:STATE RUN"
  6.011  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
  6.012  JMPL         RESTORE_MEM_AND_MEM1         @Abort
  6.013  IEEE         [V @MeasQuery][I]
  6.014  MATH         M[15] = MEM
  6.015  HEAD         Channel Reading = [MEM]
  6.016  IEEE         [D350]

  6.017  LABEL        READING3
  6.018  MATH         @Cmd = "ACQ:STATE RUN"
  6.019  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
  6.020  JMPL         RESTORE_MEM_AND_MEM1         @Abort
  6.021  IEEE         [V @MeasQuery][I]
  6.022  HEAD         Channel Reading = [MEM]
  6.023  MATH         M[16] = MEM

  6.024  MATH         M[18] = MIN(14, 16)
  6.025  MATH         M[19] = MAX(14, 16)

  6.026  MATH         BackupMEM = M[19]
  6.027  JMPL         RESTORE_MEM_AND_MEM1

  6.028  EVAL   Increment test number

# =====  Sub Tek TDS6000 Check for Trigger IEEE  ============================

# Wait up to 5 s for DUT to trigger.
  7.001  LABEL        CHECK_FOR_TRIGGER

  7.002  DO
  7.003  MATH         L[1] = 0

  7.004  DO
  7.005  IEEE         TRIG:STATE?[I$]
  7.006  MATH         @Triggered = FIND(MEM2, "TRIG", 1)
  7.007  WAIT         [D1000]
  7.008  MATH         L[1] = L[1] + 1
  7.009  UNTIL        @Triggered || (L[1] > 5)

  7.010  IF           NOT(@Triggered)
  7.011  OPBR         -z The DUT is not triggered.  Check connections and
  7.011  OPBR         select "Yes" to repeat.  Alternatively, manually
  7.011  OPBR         adjust DUT trigger level for a triggered signal
  7.011  OPBR         and select "No" to proceed.
  7.011  OPBR
  7.011  OPBR         Do you wish to repeat the test?
  7.012  MATH         @Triggered = NOT(MEM1)
  7.013  ENDIF

  7.014  UNTIL        @Triggered

  7.015  LABEL        RESTORE_MEM_AND_MEM1
  7.016  MATH         MEM = BackupMEM; MEM1 = BackupMEM1
  7.017  END
